@@ -1,4 +1,4 @@
-/* $Id: gweather-about.c,v 1.25 2006/08/21 16:44:35 davyd Exp $ */
+/* $Id: gweather-about.c 10289 2007-07-17 06:20:57Z jhaitsma $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -20,6 +20,8 @@
 
 #include <gnome.h>
 
+#define GWEATHER_I_KNOW_THIS_IS_UNSTABLE
+
 #include "gweather.h"
 #include "gweather-about.h"
 
@@ -46,7 +48,6 @@ void gweather_about_run (GWeatherApplet *gw_applet)
     };
 
     gtk_show_about_dialog (NULL,
-	"name",		_("Weather Report"),
 	"version",	VERSION,
 	"copyright",	_("\xC2\xA9 1999-2005 by S. Papadimitriou and others"),
 	"comments",	_("A panel application for monitoring local weather "
