@@ -1,7 +1,7 @@
 #ifndef __GWEATHER_ABOUT_H_
 #define __GWEATHER_ABOUT_H_
 
-/* $Id: gweather-about.h,v 1.2 1999/07/19 00:14:25 spapadim Exp $ */
+/* $Id: gweather-about.h 4693 2002-07-10 23:48:58Z mmclouglin $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -13,8 +13,15 @@
  *
  */
 
-extern void gweather_about_run (void);
+#define GWEATHER_I_KNOW_THIS_IS_UNSTABLE
 
+#include "gweather.h"
+
+G_BEGIN_DECLS
+
+extern void gweather_about_run (GWeatherApplet *gw_applet);
+
+G_END_DECLS
 
 #endif /* __GWEATHER_ABOUT_H_ */
 
